@@ -595,28 +595,28 @@ plot.see_parameters_model <- function(x,
 
 .meta_measure <- function(meta_measure) {
   switch(meta_measure,
-    "MD" = "Raw Mean Difference",
-    "SMDH" = ,
-    "SMD" = "Standardized Mean Difference",
-    "ROM" = "Log transformed Ratio of Means",
-    "D2ORL" = ,
-    "D2ORN" = "Transformed Standardized Mean Difference",
-    "UCOR" = ,
-    "COR" = "Raw Correlation Coefficient",
-    "ZCOR" = "Z transformed Correlation Coefficient",
-    "PHI" = "Phi Coefficient",
-    "RR" = "Log Risk Ratio",
-    "OR" = "Log Odds Ratio",
-    "RD" = "Risk Difference",
-    "AS" = "Root transformed Risk Difference",
-    "PETO" = "Peto's Log Odds Ratio",
-    "PBIT" = "Standardized Mean Difference (Probit-transformed)",
-    "OR2DL" = ,
-    "OR2DN" = "Standardized Mean Difference (Odds Ratio-transformed)",
-    "IRR" = "Log Incidence Rate Ratio",
-    "IRD" = "Incidence Rate Difference",
-    "IRSD" = "Square Root transformed Incidence Rate Difference",
-    "GEN" = "Generic Estimate",
+    MD = "Raw Mean Difference",
+    SMDH = ,
+    SMD = "Standardized Mean Difference",
+    ROM = "Log transformed Ratio of Means",
+    D2ORL = ,
+    D2ORN = "Transformed Standardized Mean Difference",
+    UCOR = ,
+    COR = "Raw Correlation Coefficient",
+    ZCOR = "Z transformed Correlation Coefficient",
+    PHI = "Phi Coefficient",
+    RR = "Log Risk Ratio",
+    OR = "Log Odds Ratio",
+    RD = "Risk Difference",
+    AS = "Root transformed Risk Difference",
+    PETO = "Peto's Log Odds Ratio",
+    PBIT = "Standardized Mean Difference (Probit-transformed)",
+    OR2DL = ,
+    OR2DN = "Standardized Mean Difference (Odds Ratio-transformed)",
+    IRR = "Log Incidence Rate Ratio",
+    IRD = "Incidence Rate Difference",
+    IRSD = "Square Root transformed Incidence Rate Difference",
+    GEN = "Generic Estimate",
     "Estimate"
   )
 }
